export class Chart {

    constructor($canvas) {
        this.$canvas = $canvas
    }

    render(chart) {
        const context = this.$canvas.getContext('2d')
        const [width, height] = [this.$canvas.width, this.$canvas.height]

        context.lineCap = 'round'
        context.lineJoin = 'round'
        context.textBaseline = 'middle'
        context.textAlign = 'center'
        context.fillStyle = 'white'
        context.fillRect(0, 0, width, height)

        // title
        if (chart.title) {
            context.fillStyle = '#CE5127'
            context.font = '18px sans-serif'
            context.fillText(chart.title, width / 2, 20)
        }

        // axes
        context.save()

        context.font = '18px arial'
        context.fillStyle = 'black'
        context.fillText(chart.xAxis.title, width / 2, height - 20)

        context.translate(0, height / 2)
        context.rotate(- Math.PI / 2)
        context.fillText(chart.yAxis.title, 0, 10)

        context.restore()

        // reference line (49 stones / 2)
        context.beginPath()
        context.strokeStyle = 'gray'
        context.moveTo(30, height / 2)
        context.lineTo(width, height / 2)
        context.stroke()

        // current move
        context.beginPath()
        context.strokeStyle = '#CE5127'
        context.moveTo(20, 0)
        context.lineTo(20, height)
        context.stroke()

        // lines
        const maxWhiteStones = Math.max(...chart.series[0].data)
        const maxBlackStones = Math.max(...chart.series[1].data)
        const maxStones = maxWhiteStones + maxBlackStones

        context.save()
        context.translate(0, height)
        context.scale(1, -1)

        context.shadowColor = 'black'
        context.shadowBlur = 2
        for (const serie of chart.series) {
            if (serie.data && serie.data.length) {
                context.beginPath()
                context.strokeStyle = serie.name
                context.lineWidth = 4
                let first = true
                serie.data.forEach((point, index) => {
                    const x = 30 + index * (width - 30) / serie.data.length
                    const y = 30 + (point * (height - 30) / maxStones)
                    if (first) {
                        context.moveTo(x, y)
                        first = false
                    } else {
                        context.lineTo(x, y)
                    }
                })
                context.stroke()
            }
        }

        context.restore()
    }
}

