// Forsyth-Edwards Notation

import { Board } from '../board/board.js'
import { Move } from '../board/move.js'

export class FenLoader /* extends Loader */ {

    parse(text) {
        // filter moves and players
        let players = text.split('\n').filter(line => line.split(/\s+/).length == 2)
        players = players.map(player => player.split(' ')[1])

        let moves = text.split('\n').filter(line => line.split(/\s+/).length > 2)
        const game = this.buildBoards(moves)

        moves = moves.map(move => move.split(' ')[0])     // extract move
        return { moves, players, game }
    }

    buildBoards(moves) {
        const boards = []
        for (const fen of moves) {
            const board = this.getBoard(fen)
            boards.push(board)
        }
        return boards
    }

    getBoard(fenLine) {
        // e.g. c6a5 o2xxxo/1x1xx2/xxo1o2/1xoxx2/1oo4/7/2x3x o 0 15
        const [move, fenString, color, halfmove, fullMove] = fenLine.split(' ')
        const { source, destination } = Move.fromSAN(move)

        return {
            move,
            source,
            destination,
            board: Board.fromFen(fenString)
        }
    }
}
